# -*- coding: utf-8 -*-

import os, sys
# ensure citruleaf.py is in path
sys.path.insert(1, os.path.realpath( os.pardir ) )

import unittest
import citrusleaf as cl

class TestSetPassword(unittest.TestCase):

    @classmethod
    def setUpClass(cls):
        
        cls.cluster_with_user_admin = cl.CitrusleafCluster()
        cls.cluster_with_user_admin.setUser('testuauser', cl.hashpassword('aerospike'))
        cl.cluster_setHost(cls.cluster_with_user_admin, 'localhost', '3000')

        cls.cluster_with_read_user = cl.CitrusleafCluster()
        cls.cluster_with_read_user.setUser('testreaduser', cl.hashpassword('aerospike'))
        cl.cluster_setHost(cls.cluster_with_read_user, 'localhost', '3000')
    
    @classmethod
    def tearDownClass(cls):

        del(cls.cluster_with_user_admin)
        del(cls.cluster_with_read_user)

    def test_setPassword(self):

        status = cl.setPassword(TestSetPassword.cluster_with_user_admin, 'testsauser', cl.hashpassword('p@ssword'))

        self.assertEqual(0, status)

        status = cl.setPassword(TestSetPassword.cluster_with_user_admin, 'testsauser', cl.hashpassword('aerospike'))

        self.assertEqual(0, status)

    def test_setPassword_for_non_existent_user(self):

        status = cl.setPassword(TestSetPassword.cluster_with_user_admin, 'some_user', cl.hashpassword('p@ssword'))

        self.assertEqual(60, status)

    def test_setPassword_with_empty_password(self):

        status = cl.setPassword(TestSetPassword.cluster_with_user_admin, 'testsauser', cl.hashpassword(''))

        self.assertEqual(0, status)

        status = cl.setPassword(TestSetPassword.cluster_with_user_admin, 'testsauser', cl.hashpassword('aerospike'))

        self.assertEqual(0, status)

    def test_setPassword_with_other_than_useradmin_user(self):

        status = cl.setPassword(TestSetPassword.cluster_with_read_user, 'testsauser', cl.hashpassword('p@ssword'))

        self.assertEqual(81, status)


if __name__ == "__main__":
    unittest.main()
